@@ -1,18 +1,21 @@
+from django.forms.fields import CharField
+from django.utils.translation import ugettext_lazy as _
+
 from cms import __version__ as cms_version
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
-from django.forms.fields import CharField
-from django.utils.translation import ugettext_lazy as _
 from djangocms_text_ckeditor.widgets import TextEditorWidget
 from djangocms_text_ckeditor.models import Text
 from djangocms_text_ckeditor.utils import plugin_tags_to_user_html
 from djangocms_text_ckeditor.forms import TextForm
 
+
 try:
     import cms.cms_toolbar
 except ImportError:
     raise Exception("You need at least django CMS 3.0 for this version of djangocms-text-ckeditor")
 
+
 class TextPlugin(CMSPluginBase):
     model = Text
     name = _("Text")
@@ -20,21 +23,22 @@ class TextPlugin(CMSPluginBase):
     render_template = "cms/plugins/text.html"
     change_form_template = "cms/plugins/text_plugin_change_form.html"
 
-    def get_editor_widget(self, request, plugins, pk, placeholder):
+    def get_editor_widget(self, request, plugins, pk, placeholder, language):
         """
         Returns the Django form Widget to be used for
         the text area
         """
-        return TextEditorWidget(installed_plugins=plugins, pk=pk, placeholder=placeholder)
+        return TextEditorWidget(installed_plugins=plugins, pk=pk, placeholder=placeholder, plugin_language=language)
 
-    def get_form_class(self, request, plugins, pk, placeholder):
+    def get_form_class(self, request, plugins, pk, placeholder, language):
         """
         Returns a subclass of Form to be used by this plugin
         """
         # We avoid mutating the Form declared above by subclassing
         class TextPluginForm(self.form):
             pass
-        widget = self.get_editor_widget(request, plugins, pk, placeholder)
+
+        widget = self.get_editor_widget(request, plugins, pk, placeholder, language)
         TextPluginForm.declared_fields["body"] = CharField(
             widget=widget, required=False
         )
@@ -46,7 +50,8 @@ class TextPlugin(CMSPluginBase):
             self.page
         )
         pk = self.cms_plugin_instance.pk
-        form = self.get_form_class(request, plugins, pk, self.cms_plugin_instance.placeholder)
+        form = self.get_form_class(request, plugins, pk, self.cms_plugin_instance.placeholder,
+                                   self.cms_plugin_instance.language)
         kwargs['form'] = form  # override standard form
         return super(TextPlugin, self).get_form(request, obj, **kwargs)
 
@@ -75,4 +80,5 @@ class TextPlugin(CMSPluginBase):
         obj.clean_plugins()
         super(TextPlugin, self).save_model(request, obj, form, change)
 
+
 plugin_pool.register_plugin(TextPlugin)
